FileSystemResourceProvider

Struct FileSystemResourceProvider 

pub struct FileSystemResourceProvider { /* private fields */ }
A ResourceProvider that provides resources from the local file system.

Implementations

Source

impl FileSystemResourceProvider

pub fn new(root: impl AsRef<Path>) -> Self

Returns a new provider that provides resources from the given root directory.

The root directory should be the directory that contains the assets/ and (optionally) data/ directory.