pub struct Display {
pub thirdperson_righthand: Option<Transform>,
pub thirdperson_lefthand: Option<Transform>,
pub firstperson_righthand: Option<Transform>,
pub firstperson_lefthand: Option<Transform>,
pub gui: Option<Transform>,
pub head: Option<Transform>,
pub ground: Option<Transform>,
pub fixed: Option<Transform>,
}Expand description
Specifies how a Model is displayed in different views.
Fields
thirdperson_righthand: Option<Transform>How the model is displayed when held in the right hand in third-person view.
thirdperson_lefthand: Option<Transform>How the model is displayed when held in the left hand in third-person view.
firstperson_righthand: Option<Transform>How the model is displayed when held in the right hand in first-person view.
firstperson_lefthand: Option<Transform>How the model is displayed when held in the left hand in first-person view.
gui: Option<Transform>How the model is displayed in the GUI (e.g., in the inventory).
head: Option<Transform>How the model is displayed when worn on the player’s head.
ground: Option<Transform>How the model is displayed when on the ground.
fixed: Option<Transform>How the model is displayed in an item frame.