pub struct ElementRotation {
pub origin: [f32; 3],
pub axis: Axis,
pub angle: f32,
pub rescale: bool,
}Expand description
Specifies the rotation of an Element.
Fields
origin: [f32; 3]Sets the center of the rotation according to the scheme [x, y, z].
axis: AxisSpecifies the direction of rotation.
angle: f32Specifies the angle of rotation.
Can be 45 through -45 degrees in 22.5 degree increments.
rescale: boolSpecifies whether or not to scale the faces across the whole block.
Defaults to false.