pub struct Transform {
pub rotation: [f32; 3],
pub translation: [f32; 3],
pub scale: [f32; 3],
}Expand description
Specifies the position, rotation, and scale at which a model is displayed.
Note that translations are applied to the model before rotations.
Fields
rotation: [f32; 3]Specifies the rotation of the model in degrees according to the scheme
[x, y, z].
translation: [f32; 3]Specifies the position of the model according to the scheme [x, y, z].
The unit of distance is 1/16th of a block (0.0625 meters).
The values should be clamped between -80 and 80.
scale: [f32; 3]Specifies the scale of the model according to the scheme [x, y, z].
If the value is greater than 4, it is displayed as 4.