An API for programmatically accessing Minecraft resources and associated metadata.
Resource Locations
Every resource is associated with a unique ResourceLocation, which is a
combination of a ResourceKind and a namespaced identifier.
Providers
Resources can be enumerated and loaded using the ResourceProvider trait.
This crate provides the FileSystemResourceProvider as a convenient
implementation of this trait.
Asset Pack
Resources can be ergonomically loaded through the AssetPack API.
Structs
- Asset
Pack - Top-level API for accessing Minecraft assets.
- File
System Resource Provider - A
ResourceProviderthat provides resources from the local file system. - Model
Identifier - Helper methods for dealing with model identifiers.
- Model
Resolver - Methods for resolving the properties of a
Modelwith respect to its parents. - Resource
Location - Represents a Minecraft resource location.
- Resource
Path - Represents the full path to a resource, e.g., on the local file system.
Enums
- Error
- Error types that can be returned from API methods.
- Resource
Category - The category of a resource.
- Resource
Kind - The type of a resource.
Constants
Traits
- Enumerate
Resources - Indicates that a type can enumerate available resources.
- Load
Resource - Indicates that a type can load provide the raw data of resources.
- Resource
Provider - Marker trait for types that are
EnumerateResourcesandLoadResource.
Type Aliases
- Result
- Result alias for convenience.