pub struct Element {
pub from: [f32; 3],
pub to: [f32; 3],
pub faces: HashMap<BlockFace, ElementFace>,
pub rotation: ElementRotation,
pub shade: bool,
}Expand description
A single, cube-shaped element of a Model’s geometry.
Fields
from: [f32; 3]Start point of a cuboid according to the scheme [x, y, z].
Values must be between -16 and 32.
to: [f32; 3]Stop point of a cuboid according to the scheme [x, y, z].
Values must be between -16 and 32.
faces: HashMap<BlockFace, ElementFace>Holds all the faces of the cuboid. If a face is left out, it does not render.
rotation: ElementRotationThe rotation of the element
shade: boolSpecifies if shadows are rendered (true - default), or not (false).